<?php

require_once(_PS_MODULE_DIR_ . "paczkomaty247/paczkomaty247carrierutils.php");
require_once(_PS_MODULE_DIR_ . "paczkomaty247/paczkomaty247api.php");	
require_once(_PS_MODULE_DIR_ . "paczkomaty247/paczkomaty247config.php");
require_once(_PS_MODULE_DIR_ . "paczkomaty247/paczkomaty247cart.php");
require_once(_PS_MODULE_DIR_ . "paczkomaty247/Paczkomaty247Carrier.php");

class Paczkomaty247 extends Module
{

	const INSTALL_SQL_FILE = 'install.sql';
	
	private static $INSTANCE = NULL;
	private $_postErrors = NULL;

	public $DEBUG = TRUE;
	public $paczkomaty247Config;
	public $id_lang;	
	
	public function getInstance() {
		if (!self::$INSTANCE) {
			self::$INSTANCE = new Paczkomaty247();
		}
		return self::$INSTANCE;
	}	

	public function __construct()
	{

		$this->name = 'paczkomaty247';
		$this->tab = 'Tools';
		$this->version = '0.3';
		$this->id_lang = (!isset($cookie) OR !is_object($cookie)) ? intval(Configuration::get('PS_LANG_DEFAULT')) : intval($cookie->id_lang);

		$this->limited_countries = array('pl');

		parent::__construct();

		if (true !== extension_loaded('curl')) {
			$this->warning = $this->l('this module requires php extension cURL to function properly. Please install the php extension "cURL" first');
		}
		
		if (true !== extension_loaded('openssl')) {
			$this->warning = $this->l('this module requires php extension OpenSSL to function properly. Please install the php extension "OpenSSL" first');
		}
		
		if (!function_exists('xml_parser_create')) {
			$this->warning = $this->l('this module requires php extension libxml to function properly. Please install the php extension "libxml" first');
		}

 		if (!ini_get('allow_url_fopen')) {
			$this->warning = $this->l('this module requires PHP allow_url_fopen setting to function properly.');
 		}
 		
 		if(_PS_VERSION_ <= '1.3.0.3') {
 			$this->warning = $this->l('this module requires PrestaShop version 1.3.0.4 or greater. Please upgrade first.');
 		}

		// load configuration
		$this->paczkomaty247Config = new Paczkomaty247Config();
		$this->paczkomaty247Config->loadConfig();
		
		$this->page = basename(__FILE__, '.php');
		$this->displayName = $this->l('Paczkomaty 24/7');
		$this->description = $this->l('Integracja z www.paczkomaty.pl. Dostawca Inpost/Paczkomaty 24/7');

	}

	/**
	* Install
	*
	*/
	public function install()
	{	
		if(_PS_VERSION_ <= "1.3.0.3")
			return (false);
			
		if (!file_exists(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE)) {
				return (false);
	  	}
		elseif (!$sql = file_get_contents(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE)) {
			return (false);
		}
				
		$sql = str_replace('PREFIX_', _DB_PREFIX_, $sql);
		$sql = preg_split("/;\s*[\r\n]+/",$sql);
		foreach ($sql as $query) {
			if (!empty($query)) {
				if (!Db::getInstance()->Execute(trim($query)))
				return (false);
			}
		}

		if (parent::install() == false) {
                return (false);
        }

		if ($this->registerHook('updateOrderStatus') == false
        		OR $this->registerHook('extraCarrier') == false
        		OR $this->registerHook('cart') == false) {
                	return (false);
        	}

		$this->paczkomaty247Config = new Paczkomaty247Config();
		
		if (!$this->paczkomaty247Config->saveConfig()) {
                	return (false);
        	}	
		
		return (true);
	}	

	/**
	* Uninstall
	*/
	public function uninstall()
	{
		//Carrier
		$electedCarrier = Paczkomaty247CarrierUtils::getPaczkomaty247Carriers($this->paczkomaty247Config);
		if($electedCarrier)
		{
			$electedCarrier->delete();
		}

		$this->paczkomaty247Config->uninstall();
		
		//Remove table 
		$sql = "DROP TABLE IF EXISTS `"._DB_PREFIX_."paczkomaty247_cart";
		if (!Db::getInstance()->Execute(trim($sql)))
			return (false);
		
		return parent::uninstall();
	}

	/**
	* extraCarrier
	*/
	public function hookExtraCarrier($params)
	{	
		global $smarty, $cart, $cookie, $defaultCountry;
	
		$this->hooklog("ExtraCarrier", $params);

		$electedCarrier = Paczkomaty247CarrierUtils::getPaczkomaty247Carriers($this->paczkomaty247Config);
			$this->mylog("electedCarrier=" . $this->logValue($electedCarrier,1));

		if ($electedCarrier == null) {
			//Only create carrier if it does not exist yet
			if (!Paczkomaty247CarrierUtils::carrierExists($this->paczkomaty247Config)) {
				$this->mylog("creating a new carrier");
				$electedCarrier = Paczkomaty247CarrierUtils::createPaczkomaty247Carrier($this->paczkomaty247Config);
			}
		}

		if ($electedCarrier == null) {
			return null ;
		}

		//Get address array
		$deliveryAddress = $params['address']->getFields();

		//Check if client exists
		$customer = new Customer($cart->id_customer);
		if(!$customer->id)
			return false;
		
		//Calculate location
		$api = new Paczkomaty247API();
		$electedBoxes = $api->machines_dropdown($deliveryAddress['postcode'], $customer->email, $this->paczkomaty247Config);
		if(!$electedBoxes)
			return false;
			
		//Check if client exists at paczkarnia.pl
		$isRegistered = $api->find_customer($customer->email, $this->paczkomaty247Config);
		if(!$isRegistered)
			$isRegistered['error'] = 'Error';
		
		$row['id_carrier'] = intval($electedCarrier->id);
		$row['name'] = $this->l('InPost - Paczkomaty');
		$row['delay'] = $electedCarrier->delay[$this->id_lang];
		$row['price'] = $cart->getOrderShippingCost($electedCarrier->id);
		$row['price_tax_exc'] = $cart->getOrderShippingCost($electedCarrier->id, false);
		
		$resultsArray[] = $row;

		$smarty->assign('customer', $customer);
		$smarty->assign('carriers', $resultsArray);
		$smarty->assign('paczkomaty_select', $electedBoxes);
		$smarty->assign('paczkomaty_is_registered', $isRegistered);
		
		//Check error
		if($p247error = Tools::getValue('p247error'))
		{
			//Set error message
			$errors[] = Tools::displayError($this->l('Nie wybrano Paczkomatu do którego ma być dostarczona paczka.'));
			$smarty->assign('errors', $errors);
		}

		$buffer = $this->display(__FILE__, 'paczkomaty247_carrier.tpl');		
		$buffer .=  $this->display(__FILE__, 'paczkomaty247_box.tpl');

		return $buffer;
	}
	
	public function hookCart($param)
	{
		global $cookie ;
			$this->hooklog("hookCart", $param);

		if (Tools::getIsset('ajax')) return ;
		
		$cart = $param['cart'];
		$carrier = new Paczkomaty247Carrier($cart->id_carrier, intval($this->id_lang)) ;
		if ($carrier->name != 'paczkomaty247') return ;

		//$totalCartWeight = floatval($cart->getTotalWeight());
		//$this->hooklog("hookCart totalCartWeight", array('totalCartWeight' => $totalCartWeight));
		
		$electedCarrier = Paczkomaty247CarrierUtils::getPaczkomaty247Carriers($this->paczkomaty247Config);

		// Should not be null at this point.
		if ($electedCarrier == null) {
			return null ;
		}
		
		// Process the cart for storage in dejala_cart.
		$errors = array();
		$carrierID = Tools::getValue('id_carrier');
		$boxID = Tools::getValue('paczkomaty247_box');

		if ( !empty($carrierID) && !empty($boxID) )
		{
			$id_cart = intval($param['cart']->id);
			
			$p247Cart = new Paczkomaty247Cart($id_cart);
			$p247Cart->id_box = $boxID;

			$sqlQuery = 'REPLACE INTO ' . _DB_PREFIX_ . 'paczkomaty247_cart SET id_cart = '.intval($id_cart).', id_box = "'. pSQL($p247Cart->id_box) . '";';
			$this->mylog('cart SQLQuery='. $sqlQuery);
			Db::getInstance()->Execute($sqlQuery);
		}else{
			Tools::redirect('order.php?step=2&p247error=1');
		}
	}	

	public function hookUpdateOrderStatus($params)
	{
		$this->hooklog("hookUpdateOrderStatus", $params);
		
		$newOrderStatus = $params["newOrderStatus"];
		$currentOrderStatusID = $newOrderStatus->id;
		$this->mylog("newOrderStatus=" . $this->logValue($newOrderStatus));
		$this->mylog("found currentOrderStatusID=" . $currentOrderStatusID);
		
		$triggeringStatusList = html_entity_decode(Configuration::get('P247_TRIGERRING_STATUSES'), ENT_COMPAT, 'UTF-8');
		$this->mylog("triggeringStatusList=" . $triggeringStatusList);
		$triggeringStatuses = explode(",", $triggeringStatusList);
		$orderID = $params["id_order"];
		if ((NULL !== $orderID) && (TRUE === in_array($currentOrderStatusID, $triggeringStatuses)))
		{
			$mOrder = new Order($orderID);
			$this->placeOrder($mOrder);
		}
	}
	
	public function placeOrder($mOrder)
	{
		if($this->paczkomaty247Config->apiEnable)
		{
			$orderID = $mOrder->id;
			$this->myLog("placeOrder()");
			$this->myLog("mOrder->id_carrier=".$mOrder->id_carrier);
			$mCarrier = new Carrier($mOrder->id_carrier);
			$this->myLog("mCarrier->name=".$mCarrier->name);
			if ($mCarrier->name != $this->name)
				return ;
			$this->myLog("placeOrder()");
			
			$id_cart = $mOrder->id_cart;
			$pCart = new Paczkomaty247Cart($id_cart);
			
			$this->myLog("pCart->id_delivery=" . $pCart->id_delivery);
			
			if (!$pCart->id_delivery)
			{
				$this->myLog("id_delivery is not filled");
				$delivery = array();
				$this->getInfoFromOrder($orderID, $delivery);
				$this->mylog("Sending delivery=" . $this->logValue($delivery));
				
				$api = new Paczkomaty247API();
				$this->mylog("send orderID=" . $orderID);
				
				$pOrder = $api->send_packs($this->paczkomaty247Config, $delivery);
				$this->mylog("OrderSent=" . $this->logValue($pOrder));
				
				if(!isset($pOrder[$orderID]))
				{
					$this->myLog("NOK - No orderID ".$orderID." found in return array=", $pOrder);
					return false;
				}
				
				if(isset($pOrder[$orderID]['error_key']))
				{
					$this->myLog("NOK - There was an error in return array=", $pOrder);
					return false;
				}
				
				//is ok - save packcode
				$this->mylog("updating paczkomaty247 cart cart_id=" . $id_cart);
				$packcode = $pOrder[$orderID]['packcode'];
				if($packcode)
				{
					$this->mylog("updating paczkomaty cart id_delivery=" . $packcode);
					$pCart->id_delivery = $packcode;
					
					//Check if deliverycode
					if(isset($pOrder[$orderID]['customerdeliveringcode']))
						$pCart->deliverycode = $pOrder[$orderID]['customerdeliveringcode'];
					
					$pCart->update();
				}
				
				$this->myLog("OK -  Order sent to paczkomaty.pl");
			}
		}
	}
	
	public function getInfoFromOrder($orderID, &$delivery)
	{
		$mOrder = new Order($orderID);
		if (NULL !== $mOrder) {
			
			$id_cart = $mOrder->id_cart;
			$delivery[$mOrder->id] = array();
			$cart = new Cart($id_cart);
			
			$pCart = new Paczkomaty247Cart($id_cart);
			if (NULL !== $pCart)
			{
				$delivery[$mOrder->id]['boxMachineName'] = $pCart->id_box;
 				$delivery[$mOrder->id]['alternativeBoxMachineName'] = NULL;
			} 	
			
			$client = new Customer($mOrder->id_customer);
			if (NULL != $client)
				$delivery[$mOrder->id]['adreseeEmail'] = $client->email;
				
			$delivery_address = new Address($mOrder->id_address_delivery);
			if (NULL != $delivery_address)
			{
				$delivery[$mOrder->id]['phoneNum'] = $delivery_address->phone_mobile;
				if(!$delivery[$mOrder->id]['phoneNum'])
					$delivery[$mOrder->id]['phoneNum'] = $delivery_address->phone;
				
			}
			
			$delivery[$mOrder->id]['senderEmail'] = $this->paczkomaty247Config->apiLogin;
			$delivery[$mOrder->id]['packType'] = $this->paczkomaty247Config->apipacktype;
			$delivery[$mOrder->id]['insuranceAmount'] = $cart->getOrderTotal();
			$delivery[$mOrder->id]['onDeliveryAmount'] = 0;
			
			/* Set order number */
			$delivery[$mOrder->id]['customerRef'] = $this->l('Order: #').sprintf("%06d", $mOrder->id);
			
		}
		return ($delivery);
	}

	public function hooklog($hookname, $params) {
		$this->mylog($hookname);
		$this->mylog("\r\nparams" . $this->logValue($params), 1);
	}
	
	public function mylog($msg) {
		if ($this->DEBUG) {
			require_once(dirname(__FILE__) . "/MyLogUtils.php");
				$myFile = dirname(__FILE__) . "/logFile.txt";
				MyLogUtils::myLog($myFile, $msg);
		}
	}
	
	public function logValue($mvalue, $lvl=0) {
		if (!$this->DEBUG)
			return ("");
		require_once(dirname(__FILE__) . "/MyLogUtils.php");
		return (MyLogUtils::logValue($mvalue, $lvl));
	}
	
	/**
	 * Shows configure option
	 * 
	 */
	
	public function getContent()
	{
		$this->_html = '<h2>Inpost / Paczkomaty 24/7</h2>';
		
		if (isset($_POST['submitPaczkomaty247']))
		{
			if (empty($_POST['apiurl']))
				$this->_postErrors[] = $this->l('Musisz wprowadzić adres URL do API.');
			elseif(!Validate::isAbsoluteUrl($_POST['apiurl']))
				$this->_postErrors[] = $this->l('Wprowadzony adres API URL jest niepoprawny.');
			else
			{
				//@TODO - check API return value
			}
			
			if (floatval($_POST['tax']) < 0)
				$this->_postErrors[] = $this->l('Musisz wprowadzić stawkę podatku VAT.');
			elseif(!Validate::isFloat($_POST['tax']))
				$this->_postErrors[] = $this->l('Wprowadzona stawka podatku VAT nie jest liczbą.');
			elseif(floatval($_POST['tax']) < 0 OR floatval($_POST['tax']) > 100)
				$this->_postErrors[] = $this->l('Wprowadzona stawka podatku VAT jest błędna.');

			if (floatval($_POST['price']) < 0)
				$this->_postErrors[] = $this->l('Musisz wprowadzić kwotę przesyłki.');
			elseif(!Validate::isFloat($_POST['price']))
				$this->_postErrors[] = $this->l('Kwota przesyłki nie jest liczbą.');
			elseif(floatval($_POST['price'] < 0))
				$this->_postErrors[] = $this->l('Kwota przesyłki nie może być ujemna.');
				
			if(array_key_exists('apiEnable', $_POST))
			{
				if($_POST['apiEnable'])
				{
					if($_POST['apilogin'] && $_POST['apipw'])
					{						
						//Check API login
						$api = new Paczkomaty247API();
						$api_data_test = $api->get_packs_by_sender($_POST['apilogin'], $_POST['apipw'], $this->paczkomaty247Config, array('startdate' => '2010-01-01', 'enddate' => '2010-01-01'));
						
						if(array_key_exists('error', $api_data_test))
						{
							$_POST['apiEnable'] = 0;
							$this->_postErrors[] = $api_data_test['error']['value'];
						}
						
					}else{
						$this->_postErrors[] = $this->l('Aby włączyć obsługę Managera Paczek wprowadź poprawny login i hasło.');
						$_POST['apiEnable'] = 0;						
					}
				}else{
					//Set to disabled
					$_POST['apiEnable'] = 0;
					$_POST['apilogin'] = false;
					$_POST['apipw'] = false;
				}
			}
			
			switch($_POST['apipacktype'])
			{
				case 'A':
				case 'B':
				case 'C':
					
					//ALL OK
					break;
				
				default:
					$this->_postErrors[] = $this->l('Błędna wartość pola \'Typ paczki\'.');
				
			}
				
			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('P247_API_URL', $_POST['apiurl']);
				Configuration::updateValue('P247_TAX', floatval($_POST['tax']));
				Configuration::updateValue('P247_PRICE', floatval($_POST['price']));
				Configuration::updateValue('P247_API_LOGIN', $_POST['apilogin']);
				Configuration::updateValue('P247_API_ENABLE', intval($_POST['apiEnable']));
				Configuration::updateValue('P247_API_LOGIN', $_POST['apilogin']);
				Configuration::updateValue('P247_API_PW', $_POST['apipw']);
				Configuration::updateValue('P247_API_AUTO_LABELS', intval($_POST['apiautolabels']));
				Configuration::updateValue('P247_API_SELF_SEND', intval($_POST['apiselfsend']));
				Configuration::updateValue('P247_API_PACK_TYPE', $_POST['apipacktype']);
				
				//Reload config
				$this->paczkomaty247Config->loadConfig();
				
				$this->displayConf();
			}else
				$this->displayErrors();
			
		}
		
		$this->displayFormSettings();
		return $this->_html;
	}
	
	public function displayFormSettings()
	{
		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Ustawienia').'</legend>
			<label>'.$this->l('API URL').'</label>
			<div class="margin-form">
				<input type="text" size="70" name="apiurl" value="'.$this->paczkomaty247Config->apiURL.'" />
				<p class="clear">'.$this->l('Adres interfejsu API bez / na końcu np. <i>http://api.paczkomaty.pl</i>').'</p>
			</div>
			<label>'.$this->l('Cena (netto)').'</label>
			<div class="margin-form">
				<input type="text" size="10" name="price" value="'.$this->paczkomaty247Config->price.'" />
				<p class="clear">'.$this->l('Koszt przesyłki netto').'</p>
			</div>
			<label>'.$this->l('Stawka (VAT)').'</label>
			<div class="margin-form">
				<input type="text" size="10" name="tax" value="'.floatval($this->paczkomaty247Config->tax).'" /> %
				<p class="clear">'.$this->l('Stawka podatku VAT usługi dostawy').'</p>
			</div>
			<center><input type="submit" name="submitPaczkomaty247" value="'.$this->l('Zapisz').'" class="button" /></center>
		</fieldset>
		<br /><br />
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Manager Paczek').'</legend>
			<label>'.$this->l('Włącz').'</label>
			<div class="margin-form" style="padding-top: 5px;">
				<label class="t" for="P247_API_ENABLE_on"><img src="../img/admin/enabled.gif" alt="Tak" title="Tak"></label>
				<input name="apiEnable" id="P247_API_ENABLE_on" value="1"';
		if($this->paczkomaty247Config->apiEnable)
			$this->_html .= ' checked="checked" ';
		$this->_html .= ' type="radio">
				<label class="t" for="P247_API_ENABLE_on"> Tak</label>
				<label class="t" for="P247_API_ENABLE_off"><img src="../img/admin/disabled.gif" alt="Nie" title="Nie" style="margin-left: 10px;"></label>
				<input name="apiEnable" id="P247_API_ENABLE_off" value="0"';
		if(!$this->paczkomaty247Config->apiEnable)
			$this->_html .= ' checked="checked" ';		
		$this->_html .= 'type="radio">
				<label class="t" for="P247_API_ENABLE_off"> Nie</label>
				<p class="clear">'.$this->l('Włącz integrację z Managerem Paczek').'</p>
			</div>
			<label>'.$this->l('Login').'</label>
			<div class="margin-form">
				<input type="text" size="20" autocomplete="off" name="apilogin" value="'.$this->paczkomaty247Config->apiLogin.'" />
				<p class="clear">'.$this->l('Login do konta paczkomaty.pl (Manager Paczek)').'</p>
			</div>
			<label>'.$this->l('Hasło').'</label>
			<div class="margin-form">
				<input type="password" size="20" autocomplete="off" name="apipw" value="'.$this->paczkomaty247Config->apiPw.'" />
				<p class="clear">'.$this->l('Hasło').'</p>
			</div>
			<label>'.$this->l('Generuj etykietę').'</label>
			<div class="margin-form">
			<label class="t" for="P247_API_AUTO_LABELS_on"><img src="../img/admin/enabled.gif" alt="Tak" title="Tak"></label>
			<input name="apiautolabels" id="P247_API_AUTO_LABELS_on" value="1"';
		if($this->paczkomaty247Config->apiautolabels)
			$this->_html .= ' checked="checked" ';
		$this->_html .= 'type="radio">
			<label class="t" for="P247_API_AUTO_LABELS_on"> Tak</label>
			<label class="t" for="P247_API_AUTO_LABELS_off"><img src="../img/admin/disabled.gif" alt="Nie" title="Nie" style="margin-left: 10px;"></label>
			<input name="apiautolabels" id="P247_API_AUTO_LABELS_off" value="0"';
		if(!$this->paczkomaty247Config->apiautolabels)
			$this->_html .= ' checked="checked" ';
		$this->_html .= 'type="radio">
			<label class="t" for="P247_API_AUTO_LABELS_off"> Nie</label>
			<p class="clear">'.$this->l('Parametr określający, czy przesyłki utworzone przez moduł będą miały ustawiony automatycznie status Prepared (TAK), czy też Created (NIE). Drugi przypadek oznacza konieczność wygenerowania etykiet dla przesyłek w programie Manager Paczek (dopiero wówczas paczki zostaną przekazane do wysyłki).').'</p>
			</div>
			<label>'.$this->l('Nadanie w paczkomacie').'</label>
			<div class="margin-form">
			<label class="t" for="P247_API_SELF_SEND_on"><img src="../img/admin/enabled.gif" alt="Tak" title="Tak"></label>
			<input name="apiselfsend" id="P247_API_SELF_SEND_on" value="1"';
		if($this->paczkomaty247Config->apiselfsend)
			$this->_html .= ' checked="checked" ';
		$this->_html .= 'type="radio">
			<label class="t" for="P247_API_SELF_SEND_on"> Tak</label>
			<label class="t" for="P247_API_SELF_SEND_off"><img src="../img/admin/disabled.gif" alt="Nie" title="Nie" style="margin-left: 10px;"></label>
			<input name="apiselfsend" id="P247_API_SELF_SEND_off" value="0"';
		if(!$this->paczkomaty247Config->apiselfsend)
			$this->_html .= ' checked="checked" ';
		$this->_html .= 'type="radio">
			<label class="t" for="P247_API_SELF_SEND_off"> Nie</label>
			<p class="clear">'.$this->l('Parametr określający, czy przesyłki utworzone przez moduł będą nadawane w oddziale (lub odbierane przez kuriera dla nadawców z umową) (NIE) czy bezpośrednio w paczkomacie (TAK)').'</p>
			</div>
			<label>'.$this->l('Typ paczki').'</label>
			<div class="margin-form">
			<select name="apipacktype">
				<option value="A"'; if($this->paczkomaty247Config->apipacktype == 'A') $this->_html .= ' selected="selected"'; $this->_html .= '>A (8 x 38 x 64 cm)</option>
				<option value="B"'; if($this->paczkomaty247Config->apipacktype == 'B') $this->_html .= ' selected="selected"'; $this->_html .= '>B (19 x 38 x 64 cm)</option>
				<option value="C"'; if($this->paczkomaty247Config->apipacktype == 'C') $this->_html .= ' selected="selected"'; $this->_html .= '>C (41 x 38 x 64 cm)</option>
			</select>
			<p class="clear">'.$this->l('Rozmiar paczki').'</p>
			</div>
			<center><input type="submit" name="submitPaczkomaty247" value="'.$this->l('Zapisz').'" class="button" /></center>
		</fieldset>
		</form>';
	}
	
	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Potwierdzenie').'" />
			'.$this->l('Ustawienia zapisane').'
		</div>';
	}
	
	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('Wystapily') : $this->l('Wystapil')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('bledy') : $this->l('blad')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}

	public function displayInfoByCart($id_cart)
	{
		$this->hooklog("displayInfoByCart", $id_cart);
		$this->myLog("POST=" . $this->logValue($_POST));
		
		$p247Cart = new Paczkomaty247Cart($id_cart);
		
		if ($p247Cart && isset($p247Cart->id_box))
		{
			//Get info about selected box;
			$api = new Paczkomaty247API();
			$electedBox = $api->machine_info($p247Cart->id_box, $this->paczkomaty247Config);
			
			$_html = '</fieldset><br />';
			$_html .= '<fieldset style="width: 400px;">';
			$_html .= '<legend><img src="../modules/paczkomaty247/logo.gif"> '.$this->l('InPost/Paczkomaty 24/7').'</legend>';
			$_html .= 'Wybrany paczkomat: <b>'.$p247Cart->id_box.'</b><br /><br />';
			
			if($p247Cart->id_delivery)
			{
				$_html .= 'Numer nadania: <b>'.$p247Cart->id_delivery.'</b><br />';
				if($p247Cart->deliverycode)
					$_html .= 'Kod nadania: <b>'.$p247Cart->deliverycode.'</b><br />';
				
				if($this->paczkomaty247Config->apiautolabels)
				{
					$_html .= 'Pobierz etykietę: <a href=\'/modules/paczkomaty247/etykieta.php?id='.$p247Cart->id_delivery.'\'><img src=\'/modules/paczkomaty247/pdf.gif\' title=\'Pobierz etykietę\' /></a><br />';
					if(!$p247Cart->deliverycode)
						$_html .= 'Drukuj potwierdzenie: <a href=\'/modules/paczkomaty247/potwierdzenie.php?id='.$p247Cart->id_delivery.'\'><img src=\'/modules/paczkomaty247/pdf.gif\' title=\'Drukuj potwierdzenie\' /></a><br />';
				}
				
				$_html .= '<br />';
			}
			
			if($electedBox)
			{
				$_html .= "Miasto: <b>".$electedBox['postcode']."</b>, <b>".$electedBox['town']."</b><br />";
				$_html .= "Ulica: <b>".$electedBox['street']." ".$electedBox['buildingnumber']."</b><br />";
				$_html .= 'Godziny pracy: <b>'.$electedBox['operatinghours']."</b><br />";
				$_html .= 'Opis: '.$electedBox['locationdescription']."<br />";
				$_html .= 'Pobranie: '.$electedBox['paymenttype']."<br />";
				if($electedBox['paymentpointdescr'])	
					$_html .= "Płatność: ".$electedBox['paymentpointdescr']."<br />";
				
			}else
				$_html .= '<h4 style="color: red; text-align: center;">Nie znaleziono wybranego id w bazie paczkomaty.pl</h4>';
				
			$_html .= '</fieldset><br />';
			
			
		}else{
			// Error - no object or box_id found
			$_html = 'ERROR';
		}
		
		
		return $_html;
	}
}